@@ -3,32 +3,36 @@ simple Git module, where needed via powershell
 """
 from typing import Union
 import subprocess
-import os
 from pathlib import Path
 from typing import Union, List, Optional
+from packaging.version import parse
 
 
 def _run_git(
     cmd: List[str],
-    repo: Optional[str] = None,
+    repo: Optional[Union[Path, str]] = None,
     expect_stderr=False,
     capture_output=True,
+    echo_output=True,
 ):
     "run a external (git) command in the repo's folder and deal with some of the errors"
     try:
         if repo:
-            repo = repo.replace("\\", "/")
-            result = subprocess.run(cmd, capture_output=capture_output, check=True, cwd=os.path.abspath(repo))
+            if isinstance(repo, str):
+                repo = Path(repo)
+            result = subprocess.run(cmd, capture_output=capture_output, check=True, cwd=repo.absolute().as_posix())
         else:
             result = subprocess.run(cmd, capture_output=capture_output, check=True)
-    except subprocess.CalledProcessError as e:
+    except (NotADirectoryError, FileNotFoundError) as e:  # pragma: no cover
+        return None
+    except subprocess.CalledProcessError as e:  # pragma: no cover
         # add some logging for github actions
         print("Exception on process, rc=", e.returncode, "output=", e.output)
         return None
     if result.stderr != b"":
         if not expect_stderr:
             raise Exception(result.stderr.decode("utf-8"))
-        if capture_output:
+        if capture_output and echo_output:  # pragma: no cover
             print(result.stderr.decode("utf-8"))
 
     if result.returncode < 0:
@@ -36,12 +40,17 @@ def _run_git(
     return result
 
 
-def clone(remote_repo: str, path: Path, shallow=False) -> bool:
-    "git clone --depth 0 <remote> <directory>"
+def clone(remote_repo: str, path: Path, shallow=False, tag: Optional[str] = None) -> bool:
+    "git clone [--depth 1] [--branch <tag_name>] <remote> <directory>"
     cmd = ["git", "clone"]
     if shallow:
         cmd += ["--depth", "1"]
-    cmd += [remote_repo, str(path)]
+    if tag in ("latest", "master"):
+        tag = None
+    if not tag:
+        cmd += [remote_repo, str(path)]
+    else:
+        cmd += [remote_repo, "--branch", tag, str(path)]
     result = _run_git(cmd, expect_stderr=True, capture_output=False)
     if result:
         return result.returncode == 0
@@ -49,18 +58,19 @@ def clone(remote_repo: str, path: Path, shallow=False) -> bool:
         return False
 
 
-def get_tag(repo: Optional[str] = None, abbreviate: bool = True) -> Union[str, None]:
+def get_tag(repo: Optional[Union[str, Path]] = None, abbreviate: bool = True) -> Union[str, None]:
     """
     get the most recent git version tag of a local repo
-    repo should be in the form of : repo = "./micropython"
+    repo Path should be in the form of : repo = "./repo/micropython"
 
     returns the tag or None
     """
     if not repo:
-        repo = "."
-    repo = repo.replace("\\", "/")
+        repo = Path(".")
+    elif isinstance(repo, str):
+        repo = Path(repo)
 
-    result = _run_git(["git", "describe"], repo=repo, expect_stderr=True)
+    result = _run_git(["git", "describe"], repo=repo.as_posix(), expect_stderr=True)
     if not result:
         return None
     tag: str = result.stdout.decode("utf-8")
@@ -68,7 +78,7 @@ def get_tag(repo: Optional[str] = None, abbreviate: bool = True) -> Union[str, N
     if abbreviate and "-" in tag:
         # this may or not be the latest on the main branch
         # result = _run_git(["git", "rev-parse", "--abbrev-ref", "HEAD"], repo=repo, expect_stderr=True)
-        result = _run_git(["git", "status", "--branch"], repo=repo, expect_stderr=True)
+        result = _run_git(["git", "status", "--branch"], repo=repo.as_posix(), expect_stderr=True)
         if result:
             lines = result.stdout.decode("utf-8").replace("\r", "").split("\n")
             if lines[0].startswith("On branch"):
@@ -79,11 +89,28 @@ def get_tag(repo: Optional[str] = None, abbreviate: bool = True) -> Union[str, N
     return tag
 
 
-def checkout_tag(tag: str, repo: Optional[str] = None) -> bool:
+def get_tags(repo: Optional[Path] = None, minver: Optional[str] = None) -> List[str]:
+    """
+    get list of tag of a local repo
+    """
+    if not repo:
+        repo = Path(".")
+
+    result = _run_git(["git", "tag", "-l"], repo=repo.as_posix(), expect_stderr=True)
+    if not result or result.returncode != 0:
+        return []
+    tags = result.stdout.decode("utf-8").replace("\r", "").split("\n")
+    tags = [tag for tag in tags if tag.startswith("v")]
+    if minver:
+        tags = [tag for tag in tags if parse(tag) >= parse(minver)]
+    return sorted(tags)
+
+
+def checkout_tag(tag: str, repo: Optional[Union[str, Path]] = None) -> bool:
     """
     checkout a specific git tag
     """
-    cmd = ["git", "checkout", "tags/" + tag, "--quiet", "--force"]
+    cmd = ["git", "checkout", "tags/" + tag, "--detach", "--quiet", "--force"]
     result = _run_git(cmd, repo=repo, expect_stderr=True)
     if not result:
         return False
@@ -92,7 +119,7 @@ def checkout_tag(tag: str, repo: Optional[str] = None) -> bool:
     return True
 
 
-def checkout_commit(commit_hash: str, repo: Optional[str] = None) -> bool:
+def checkout_commit(commit_hash: str, repo: Optional[Union[Path, str]] = None) -> bool:
     """
     Checkout a specific commit
     """
@@ -105,13 +132,14 @@ def checkout_commit(commit_hash: str, repo: Optional[str] = None) -> bool:
     return True
 
 
-def switch_tag(tag: str, repo: Optional[str] = None) -> bool:
+def switch_tag(tag: str, repo: Optional[Union[Path, str]] = None) -> bool:
     """
     get the most recent git version tag of a local repo"
     repo should be in the form of : path/.git
     repo = '../micropython/.git'
     returns the tag or None
     """
+
     cmd = ["git", "switch", "--detach", tag, "--quiet", "--force"]
     result = _run_git(cmd, repo=repo, expect_stderr=True)
     if not result:
@@ -121,7 +149,7 @@ def switch_tag(tag: str, repo: Optional[str] = None) -> bool:
     return True
 
 
-def switch_branch(branch: str, repo: Optional[str] = None) -> bool:
+def switch_branch(branch: str, repo: Optional[Union[Path, str]] = None) -> bool:
     """
     get the most recent git version tag of a local repo"
     repo should be in the form of : path/.git
@@ -137,7 +165,7 @@ def switch_branch(branch: str, repo: Optional[str] = None) -> bool:
     return True
 
 
-def fetch(repo: str) -> bool:
+def fetch(repo: Union[Path, str]) -> bool:
     """
     fetches a repo
     repo should be in the form of : path/.git
@@ -146,9 +174,9 @@ def fetch(repo: str) -> bool:
     """
     if not repo:
         raise NotADirectoryError
-    repo = repo.replace("\\", "/")
-    cmd = ["git", "fetch origin"]
-    result = _run_git(cmd, repo=repo)
+
+    cmd = ["git", "fetch", "--all", "--tags", "--quiet"]
+    result = _run_git(cmd, repo=repo, echo_output=False)
     if not result:
         return False
     return result.returncode == 0
